==> hyprnav-0.0.18.tar.gz: hyprnav-0.0.18/src/hyprnav/listen.py <==
import os
import sys
from hyprpy import Hyprland
from .window import showWorkspaceWindow
from playsound3 import playsound
from rich.console import Console
from .config import AppConfig
from typing import Any

# initialize console with custom log‐time format
cl: Console = Console(log_time=True, log_time_format="%Y-%m-%d %H:%M:%S")
try:
    instance = Hyprland()
except Exception as e:
    cl.print(f"[red]Error connecting to Hyprland: {e}[/red]")
    sys.exit(1)

appConfig = AppConfig()
audioFileOK = False  # by default we assume the audio file is not ok
iterations: int = 0  # number of iterations to wait for the workspace to be ready
currentSound = None  # current sound to be played

if appConfig.sound.enabled:
    # check if appConfig.sound.file exists
    if not os.path.exists(appConfig.sound.file):
        cl.print(f"[red]Audio file not found: {appConfig.sound.file}[/red]")
        sys.exit(1)

    # now the audio is ok
    audioFileOK = True


def playSound() -> None:
    global currentSound
    if audioFileOK:
        if currentSound and currentSound.is_alive():
            currentSound.stop()

        currentSound = playsound(sound=f"{appConfig.sound.file}", block=False)


def onWorkspaceChanged(sender: Any, **kwargs) -> None:
    """Handle workspace change events"""
    workspaceId = kwargs.get("workspace_id")
    workspaceName = kwargs.get("workspace_name")

    # Increment iterations counter before printing
    global iterations
    iterations += 1

    cl.print(
        f"{iterations}\t: [bold yellow]Workspace[/bold yellow]: id: {workspaceId} name: {workspaceName}"
    )

    if audioFileOK:
        playSound()

    showWorkspaceWindow(workspace=workspaceName, delay=appConfig.main_window.duration)  # type: ignore


def listen() -> None:
    """Listen for workspace changes and show a window."""
    try:
        # Connect to the Hyprland signals
        instance.signals.workspacev2.connect(onWorkspaceChanged)
        instance.watch()
    except KeyboardInterrupt:
        cl.print("[green]Interrupt by user. Exiting...[/green]")
        return

==> hyprnav-0.1.8.tar.gz: hyprnav-0.1.8/src/hyprnav/listen.py <==
import os
import sys
from hyprpy import Hyprland
from typing import Any
from nava import play
from hyprnav.config import AppConfig
from hyprnav.window import showWorkspace
from hyprnav.util import printLog

try:
    instance = Hyprland()
except Exception as e:
    printLog(f"[red]Error connecting to Hyprland: {e}[/red]")
    sys.exit(1)

appConfig = AppConfig()


audioFileOK = False  # by default we assume the audio file is not ok
iterations: int = 0  # number of iterations to wait for the workspace to be ready


if appConfig.sound.enabled:
    # check if appConfig.sound.file exists
    if not os.path.exists(appConfig.sound.file):
        printLog(f"[red]Audio file not found: {appConfig.sound.file}[/red]")
        sys.exit(1)
    else:
        # now the audio is ok
        audioFileOK = True


def playSound() -> None:
    if audioFileOK:
        play(appConfig.sound.file, async_mode=True, loop=False)


def onWorkspaceChanged(sender: Any, **kwargs) -> None:
    """Handle workspace change events"""
    workspaceId = kwargs.get("workspace_id")
    workspaceName: str = str(kwargs.get("workspace_name"))

    # Increment iterations counter before printing
    global iterations
    iterations += 1

    printLog(
        f"{iterations}\t: [bold yellow]Workspace[/bold yellow]: id: {workspaceId} name: {workspaceName}"
    )

    if audioFileOK:
        playSound()

    showWorkspace(workspaceID=workspaceName)


def listen() -> None:
    """Listen for workspace changes and show a window."""
    try:
        # Connect to the Hyprland signals
        instance.signals.workspacev2.connect(onWorkspaceChanged)
        instance.watch()
    except KeyboardInterrupt:
        printLog("[green]Interrupt by user. Exiting...[/green]")
        return
